==> amf-api-contract_2.12-5.0.0-RC.0-sources.jar: amf/apicontract/client/scala/model/domain/api/Api.scala <==
package amf.apicontract.client.scala.model.domain.api

import amf.apicontract.client.scala.model.domain.{
  EndPoint,
  License,
  Organization,
  SecuredElement,
  Server,
  ServerContainer,
  Tag
}
import amf.core.client.scala.model.StrField
import amf.core.client.scala.model.domain.NamedDomainElement
import amf.core.internal.annotations.{SourceSpec, SynthesizedField}
import amf.core.internal.metamodel.Field
import amf.core.internal.metamodel.domain.ShapeModel.Description
import amf.core.internal.parser.domain.{Annotations, Fields}
import amf.core.internal.remote.Spec
import amf.apicontract.internal.metamodel.domain.api.BaseApiModel.{License => WebApiLicense, _}
import amf.apicontract.client.scala.model.domain.security.SecurityRequirement
import amf.shapes.client.scala.model.domain.DocumentedElement
import amf.shapes.client.scala.model.domain.{CreativeWork, DocumentedElement}
import org.yaml.model.{YMap, YNode}

/**
  * Web Api internal model
  */
abstract class Api(fields: Fields, annotations: Annotations)
    extends NamedDomainElement
    with SecuredElement
    with ServerContainer
    with DocumentedElement {

  def description: StrField                      = fields.field(Description)
  def identifier: StrField                       = fields.field(Identifier)
  def schemes: Seq[StrField]                     = fields.field(Schemes)
  def accepts: Seq[StrField]                     = fields.field(Accepts)
  def contentType: Seq[StrField]                 = fields.field(ContentType)
  def version: StrField                          = fields.field(Version)
  def termsOfService: StrField                   = fields.field(TermsOfService)
  def provider: Organization                     = fields.field(Provider)
  def license: License                           = fields.field(WebApiLicense)
  override def documentations: Seq[CreativeWork] = fields.field(Documentations)
  def endPoints: Seq[EndPoint]                   = fields.field(EndPoints)
  def servers: Seq[Server]                       = fields.field(Servers)
  def tags: Seq[Tag]                             = fields(Tags)

  def withDescription(description: String): this.type                  = set(Description, description)
  def withIdentifier(identifier: String): this.type                    = set(Identifier, identifier)
  def withSchemes(schemes: Seq[String]): this.type                     = set(Schemes, schemes)
  def withEndPoints(endPoints: Seq[EndPoint]): this.type               = setArray(EndPoints, endPoints)
  def withAccepts(accepts: Seq[String]): this.type                     = set(Accepts, accepts)
  def withContentType(contentType: Seq[String]): this.type             = set(ContentType, contentType)
  def withVersion(version: String): this.type                          = set(Version, version)
  def withTermsOfService(terms: String): this.type                     = set(TermsOfService, terms)
  def withProvider(provider: Organization): this.type                  = set(Provider, provider)
  def withLicense(license: License): this.type                         = set(WebApiLicense, license)
  def withDocumentations(documentations: Seq[CreativeWork]): this.type = setArray(Documentations, documentations)
  def withServers(servers: Seq[Server]): this.type                     = setArray(Servers, servers)

  def withTags(tags: Seq[Tag]): this.type = setArray(Tags, tags)

  override def removeServers(): Unit = fields.removeField(Servers)

  def withEndPoint(path: String): EndPoint = {
    val result = EndPoint().withPath(path)
    add(EndPoints, result)
    result
  }

  def withDefaultServer(url: String): Server = withServer(url).add(SynthesizedField())

  def withServer(url: String): Server = {
    val result = Server().withUrl(url)
    add(Servers, result)
    result
  }

  def withDocumentationTitle(title: String): CreativeWork = {
    val result = CreativeWork().withTitle(title)
    add(Documentations, result)
    result
  }

  def withDocumentationUrl(url: String): CreativeWork = {
    val result = CreativeWork().withUrl(url)
    add(Documentations, result)
    result
  }

  // todo: should source spec be in the base unit?

  def sourceSpec: Option[Spec] = annotations.find(classOf[SourceSpec]).map(a => a.spec)

  /** Value , path + field value that is used to compose the id when the object its adopted */
  private[amf] override def componentId: String = "/api"

  override def nameField: Field = Name
}

==> amf-api-contract_2.12-5.0.12-RC.0-sources.jar: amf/apicontract/client/scala/model/domain/api/Api.scala <==
package amf.apicontract.client.scala.model.domain.api

import amf.apicontract.client.scala.model.domain.{
  EndPoint,
  License,
  Organization,
  SecuredElement,
  Server,
  ServerContainer,
  Tag
}
import amf.core.client.scala.model.StrField
import amf.core.client.scala.model.domain.NamedDomainElement
import amf.core.internal.annotations.SynthesizedField
import amf.core.internal.metamodel.Field
import amf.core.internal.metamodel.domain.ShapeModel.Description
import amf.core.internal.parser.domain.{Annotations, Fields}
import amf.core.internal.remote.Spec
import amf.apicontract.internal.metamodel.domain.api.BaseApiModel.{License => WebApiLicense, _}
import amf.apicontract.client.scala.model.domain.security.SecurityRequirement
import amf.shapes.client.scala.model.domain.DocumentedElement
import amf.shapes.client.scala.model.domain.{CreativeWork, DocumentedElement}
import org.yaml.model.{YMap, YNode}

/** Web Api internal model
  */
abstract class Api(fields: Fields, annotations: Annotations)
    extends NamedDomainElement
    with SecuredElement
    with ServerContainer
    with DocumentedElement {

  def description: StrField                      = fields.field(Description)
  def identifier: StrField                       = fields.field(Identifier)
  def schemes: Seq[StrField]                     = fields.field(Schemes)
  def accepts: Seq[StrField]                     = fields.field(Accepts)
  def contentType: Seq[StrField]                 = fields.field(ContentType)
  def version: StrField                          = fields.field(Version)
  def termsOfService: StrField                   = fields.field(TermsOfService)
  def provider: Organization                     = fields.field(Provider)
  def license: License                           = fields.field(WebApiLicense)
  override def documentations: Seq[CreativeWork] = fields.field(Documentations)
  def endPoints: Seq[EndPoint]                   = fields.field(EndPoints)
  def servers: Seq[Server]                       = fields.field(Servers)
  def tags: Seq[Tag]                             = fields(Tags)

  def withDescription(description: String): this.type                  = set(Description, description)
  def withIdentifier(identifier: String): this.type                    = set(Identifier, identifier)
  def withSchemes(schemes: Seq[String]): this.type                     = set(Schemes, schemes)
  def withEndPoints(endPoints: Seq[EndPoint]): this.type               = setArray(EndPoints, endPoints)
  def withAccepts(accepts: Seq[String]): this.type                     = set(Accepts, accepts)
  def withContentType(contentType: Seq[String]): this.type             = set(ContentType, contentType)
  def withVersion(version: String): this.type                          = set(Version, version)
  def withTermsOfService(terms: String): this.type                     = set(TermsOfService, terms)
  def withProvider(provider: Organization): this.type                  = set(Provider, provider)
  def withLicense(license: License): this.type                         = set(WebApiLicense, license)
  def withDocumentations(documentations: Seq[CreativeWork]): this.type = setArray(Documentations, documentations)
  def withServers(servers: Seq[Server]): this.type                     = setArray(Servers, servers)

  def withTags(tags: Seq[Tag]): this.type = setArray(Tags, tags)

  override def removeServers(): Unit = fields.removeField(Servers)

  def withEndPoint(path: String): EndPoint = {
    val result = EndPoint().withPath(path)
    add(EndPoints, result)
    result
  }

  def withDefaultServer(url: String): Server = withServer(url).add(SynthesizedField())

  def withServer(url: String): Server = {
    val result = Server().withUrl(url)
    add(Servers, result)
    result
  }

  def withDocumentationTitle(title: String): CreativeWork = {
    val result = CreativeWork().withTitle(title)
    add(Documentations, result)
    result
  }

  def withDocumentationUrl(url: String): CreativeWork = {
    val result = CreativeWork().withUrl(url)
    add(Documentations, result)
    result
  }

  /** Value , path + field value that is used to compose the id when the object its adopted */
  private[amf] override def componentId: String = "/api"

  override def nameField: Field = Name
}
